@@ -1,26 +1,29 @@
 /*
- * $Id: mouse.c,v 1.12 2003/11/26 17:31:38 tom Exp $
+ * $Id: mouse.c,v 1.15 2005/11/28 00:19:09 tom Exp $
  *
  * mouse.c -- mouse support for dialog
  *
- * Copyright 2002,2003	Thomas E. Dickey
+ * Copyright 2002-2003,2005	Thomas E. Dickey
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
- *   (at your option) any later version.
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU Lesser General Public License as
+ *  published by the Free Software Foundation; either version 2.1 of the
+ *  License, or (at your option) any later version.
  *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
+ *  This program is distributed in the hope that it will be useful, but
+ *  WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
  *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- ********/
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this program; if not, write to
+ *	Free Software Foundation, Inc.
+ *	51 Franklin St., Fifth Floor
+ *	Boston, MA 02110, USA.
+ */
 
-#include "dialog.h"
+#include <dialog.h>
+#include <dlg_keys.h>
 
 #if USE_MOUSE
 
@@ -56,7 +59,7 @@ dlg_mouse_mkbigregion(int y, int x,
 		      int step_y, int step_x,
 		      int mode)
 {
-    mseRegion *butPtr = dlg_mouse_mkregion(y, x, height, width, -(M_EVENT + code));
+    mseRegion *butPtr = dlg_mouse_mkregion(y, x, height, width, -DLGK_MOUSE(code));
     butPtr->mode = mode;
     butPtr->step_x = MAX(1, step_x);
     butPtr->step_y = MAX(1, step_y);
